@@ -1,7 +1,6 @@
 <?php
 
 require "tests.php";
-require "newobject3.php";
 
 $factory = new factory();
 
@@ -15,4 +14,4 @@ check::isnull($factory->create(7, -1), "create(7, -1) should be NULL");
 check::isnull($factory->create(0, -1), "create(0, -1) should be NULL");
 check::isnull($factory->create("bad", -1), "create(\"bad\", -1) should be NULL");
 
-?>
+check::done();
